from setuptools import setup, find_packages
import codecs
import os

VERSION = '1.0.3'
DESCRIPTION = 'An image recognition package.'

# Setting up
setup(
    name="pyrecog",
    version=VERSION,
    author="FullStackJosh",
    author_email="joshuafxs@yahoo.com",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=['pyautogui'],
    keywords=['python'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
    ]
)


import pyautogui
import os
from time import sleep

def find():
	while True:
		cwd = os.getcwd()
		for root, dirs, files in os.walk(cwd):
			for file in files:
				if file.endswith(".PNG" or ".png"):
					image = file
		if pyautogui.locateOnScreen(image) != None:
			found = True
			print ("True")
			sleep(0.5)
		else:
			found = False
			print ("False")
			sleep(0.5)
find()